@@ -1,21 +1,21 @@
 /************************************************************************************
-*  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
-*  Copyright 2018 Roman Gilg <subdiff@gmail.com>                                    *
-*                                                                                   *
-*  This program is free software; you can redistribute it and/or                    *
-*  modify it under the terms of the GNU General Public License                      *
-*  as published by the Free Software Foundation; either version 2                   *
-*  of the License, or (at your option) any later version.                           *
-*                                                                                   *
-*  This program is distributed in the hope that it will be useful,                  *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
-*  GNU General Public License for more details.                                     *
-*                                                                                   *
-*  You should have received a copy of the GNU General Public License                *
-*  along with this program; if not, write to the Free Software                      *
-*  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
-*************************************************************************************/
+ *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
+ *  Copyright 2018 Roman Gilg <subdiff@gmail.com>                                    *
+ *                                                                                   *
+ *  This program is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU General Public License                      *
+ *  as published by the Free Software Foundation; either version 2                   *
+ *  of the License, or (at your option) any later version.                           *
+ *                                                                                   *
+ *  This program is distributed in the hope that it will be useful,                  *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
+ *  GNU General Public License for more details.                                     *
+ *                                                                                   *
+ *  You should have received a copy of the GNU General Public License                *
+ *  along with this program; if not, write to the Free Software                      *
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
+ *************************************************************************************/
 #ifndef KSCREEN_DAEMON_H
 #define KSCREEN_DAEMON_H
 
@@ -46,7 +46,7 @@ class KScreenDaemon : public KDEDModule
     Q_CLASSINFO("D-Bus Interface", "org.kde.KScreen")
 
 public:
-    KScreenDaemon(QObject *parent, const QList<QVariant>&);
+    KScreenDaemon(QObject *parent, const QList<QVariant> &);
     ~KScreenDaemon() override;
 
 public Q_SLOTS:
@@ -83,7 +83,7 @@ private:
     void refreshConfig();
 
     void monitorConnectedChange();
-    void disableOutput(KScreen::OutputPtr &output);
+    void disableOutput(const KScreen::OutputPtr &output);
     void showOsd(const QString &icon, const QString &text);
 
     void updateOrientation();
@@ -91,9 +91,9 @@ private:
     std::unique_ptr<Config> m_monitoredConfig;
     bool m_monitoring;
     bool m_configDirty = true;
-    QTimer* m_changeCompressor;
-    QTimer* m_saveTimer;
-    QTimer* m_lidClosedTimer;
+    QTimer *m_changeCompressor;
+    QTimer *m_saveTimer;
+    QTimer *m_lidClosedTimer;
     KScreen::OsdManager *m_osdManager;
     OrientationSensor *m_orientationSensor;
     bool m_startingUp = true;
